|title|_
=========

.. |title| replace:: bobleesj.utils
.. _title: https://bobleesj.github.io/'

|PyPi| |Forge| |PythonVersion| |PR|

|CI| |Codecov| |Black| |Tracking|

.. |Black| image:: https://img.shields.io/badge/code_style-black-black
        :target: https://github.com/psf/black

.. |CI| image:: https://github.com/bobleesj/bobleesj.utils/actions/workflows/matrix-and-codecov-on-merge-to-main.yml/badge.svg
        :target: https://github.com/bobleesj/bobleesj.utils/actions/workflows/matrix-and-codecov-on-merge-to-main.yml

.. |Codecov| image:: https://codecov.io/gh/bobleesj/bobleesj.utils/branch/main/graph/badge.svg
        :target: https://codecov.io/gh/bobleesj/bobleesj.utils

.. |Forge| image:: https://img.shields.io/conda/vn/conda-forge/bobleesj.utils
        :target: https://anaconda.org/conda-forge/bobleesj.utils

.. |PR| image:: https://img.shields.io/badge/PR-Welcome-29ab47ff

.. |PyPi| image:: https://img.shields.io/pypi/v/bobleesj.utils
        :target: https://pypi.org/project/bobleesj.utils/

.. |PythonVersion| image:: https://img.shields.io/pypi/pyversions/bobleesj.utils
        :target: https://pypi.org/project/bobleesj.utils/

.. |Tracking| image:: https://img.shields.io/badge/issue_tracking-github-blue
        :target: https://github.com/bobleesj/'/issues


Overview
--------

``bobleesj.utils`` is a Python package that provides a collection of utility functions and classes to simplify common tasks in materials informatics. ``bobleesj.utils`` is used across scientific software projects created and maintained by @bobleesj.

.. Open-source projects using ``bobleesj.utils``
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. .. list-table::
..         :header-rows: 1
..         :widths: 5 25 40 20

..         * - #
..           - Open-source project
..           - Description
..           - Publication Link
..         * - 1
..           - `CIF Bond Analyzer (CBA) <https://github.com/bobleesj/cif-bond-analyzer>`__
..           - Computes the minimum atomic bonding distances from sites, generating histograms and pair counts.
..           - `Journal of Alloys and Compounds <https://doi.org/10.1016/j.jallcom.2023.173241>`__
..         * - 2
..           - `Structure Analyzer/Featurizer (SAF) <https://github.com/bobleesj/structure-analyzer-featurizer>`__
..           - Generates geometric features of interatomic distances, atomic environment information, and coordination numbers.
..           - `Digital Discovery <https://doi.org/10.1039/D4DD00332B>`__
..         * - 3
..           - `Composition Analyzer/Featurizer (CAF) <https://github.com/bobleesj/composition-analyzer-featurizer>`__
..           - Generates chemical compositional features and provides tools for filtering, sorting, and merging data.
..           - `Digital Discovery <https://doi.org/10.1039/D4DD00332B>`__
..         * - 4
..           - `cifkit <https://github.com/bobleesj/cifkit>`__
..           - Python package for .cif coordination geometry and atomic site analysis
..           - `JOSS <https://joss.theoj.org/papers/9016ae27b8c6fddffaae5aeb8be18d19>`__
..         * - 5
..           - `Inorganic ML descriptors <https://www.sciencedirect.com/science/article/pii/S2352340924001495>`__
..           - Thermoelectric materials performance (zT) predictions with ML
..           - `ACS Applied Materials & Interfaces <https://pubs.acs.org/doi/10.1021/acsami.4c19149>`__
..         * - 6
..           - `Crystal structure clustering with SAF/CAF <https://github.com/bobleesj/SAF-CAF-performance>`__
..           - Unsupervised ML with ~80 features and experimental validation
..           - `Journal of American Chemical Society (JACS) <https://pubs.acs.org/doi/10.1021/jacs.5c03510>`__

Getting started
---------------

Are you interested in exploring ``bobleesj.utils``? Begin with the ``Overview`` page in our online documentation at https://bobleesj.github.io/bobleesj.utils!


knowledgements
----------------

This GitHub repository is built and maintained with the help of `scikit-package <https://scikit-package.github.io/scikit-package/>`_.
